@@ -15,7 +15,7 @@ signals: Dict[int, Tuple[qtpy.QtCore.Signal, Callable]] = {}
 
 @disconnect(signals)
 def value_updated(value, item):
-    item.set({"value": item.get()})
+    item.set({"value": value})
 
 
 def set_daemon(value, property):
@@ -30,6 +30,7 @@ def Boolean(key, property, qclient):
         disabled = True
     # make item
     item = qtypes.Bool(disabled=disabled, label=key)
+    signals[id(item)] = []
     # signals and slots
     sig, func = property.updated, partial(value_updated, item=item)
     signals[id(item)].append((sig, func))
